@@ -5,7 +5,7 @@ use warnings;
 use Carp qw(croak);
 use Scalar::Util qw(weaken refaddr);
 
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 
 sub new {
     my $proto = shift;
@@ -88,11 +88,11 @@ sub as_string {
     my $complex = 0;
 
     foreach my $c (@{$self->{contents}}) {
-        if (UNIVERSAL::isa($c, __PACKAGE__) and !$c->inline) {
+        if ( eval { $c->isa( __PACKAGE__ ) and !$c->inline } ) {
             $complex = 1;
             $str .= "\n" . $c->as_string($indent . $growindent, $growindent);
         }
-        elsif (UNIVERSAL::isa($c, 'XML::API')) { # assume it is complex?
+        elsif ( eval { $c->isa( 'XML::API' ) } ) { # assume it is complex?
             $str .= "\n" . join("\n",
                 map {$_->as_string($indent . $growindent, $growindent)}
                      $c->_elements);
@@ -119,9 +119,9 @@ sub fast_string {
     return  '<'. ($self->{ns} ? $self->{ns}.':' : '') 
            . $self->{element} . $self->attrs_as_string .'>'
            . join('', map {
-                UNIVERSAL::isa($_, __PACKAGE__)
+                eval { $_->isa( __PACKAGE__ ) }
                     ? $_->fast_string
-                    : (UNIVERSAL::isa($_, 'XML::API')
+                    : (eval { $_->isa('XML::API') }
                         ? join('', map {$_->fast_string} $_->_elements)
                         : $_)
                 } @{$self->{contents}})
@@ -196,11 +196,10 @@ use strict;
 use warnings;
 use overload '""' => \&_as_string, 'fallback' => 1;
 use Carp qw(carp croak confess);
-use UNIVERSAL;
 use Scalar::Util qw(weaken refaddr);
 use XML::SAX;
 
-our $VERSION          = '0.24';
+our $VERSION          = '0.25';
 our $DEFAULT_ENCODING = 'UTF-8';
 our $ENCODING         = undef;
 our $Indent           = '  ';
@@ -382,10 +381,13 @@ sub _open {
 sub _add {
     my $self = shift;
     $self->{string} = undef;
+    if (!$self->{current}) {
+        croak 'Cannot use _add with no current element';
+    }
 
     foreach my $item (@_) {
         carp "undefined input" unless(defined($item));
-        if (UNIVERSAL::isa($item, __PACKAGE__)) {
+        if ( eval { $item->isa( __PACKAGE__ ) } ) {
             if (refaddr($item) == refaddr($self)) {
                 croak 'Cannot _add object to itself';
             }
@@ -404,14 +406,10 @@ sub _add {
             }
         }
         else {
-            if (!$self->{current}) {
-                croak 'Cannot use _add with no current element';
-            }
-
-            if (UNIVERSAL::isa($item, 'XML::API::Element')) {
+            if ( eval { $item->isa( 'XML::API::Element' ) } ) {
                 $self->{current}->add($item);
             }
-            elsif (UNIVERSAL::isa($item, 'XML::API::Cache')) {
+            elsif ( eval { $item->isa( 'XML::API::Cache' ) } ) {
                 foreach my $lang ($item->langs) {
                     $self->{langs}->{$lang} = 1;
                 }
@@ -430,7 +428,7 @@ sub _raw {
     $self->{string} = undef;
     foreach my $item (@_) {
         carp "undefined input" unless(defined($item));
-        if (ref($item) and $item->isa(__PACKAGE__)) {
+        if (ref($item) and $item->isa( __PACKAGE__ )) {
             croak 'Cannot add XML::API objects as raw';
         }
         if ($self->{current}) {
@@ -818,7 +816,7 @@ sub _goto {
             $self->{current} = undef;
             return;
         }
-        if (UNIVERSAL::isa($id, 'XML::API::Element')) {
+        if ($id->isa( 'XML::API::Element' )) {
             $self->{current} = $id;
         }
         elsif (defined($self->{ids}->{$id})) {
@@ -846,7 +844,7 @@ sub _as_string {
     }
 
     $string .= join("\n", map {
-            UNIVERSAL::isa($_, __PACKAGE__)
+            $_->isa( __PACKAGE__ )
                 ? join("\n", map {$_->as_string} $_->_elements)
                 : $_->as_string('', '  ')
         } @{$self->{elements}});
@@ -1096,14 +1094,14 @@ element names are not suitable as Perl method calls, or are otherwise funny
 =head2 $x->_add($content)
 
 Add $content to the 'current' element. If there is no current element
-then this method will carp.
+then this method will croak.
 
 If $content is a scalar (ie plain text or numbers) then the characters
 '<&">' will be XML-escaped.  If $content is another XML::API object the
 elements of that object will be added to content tree.
 
-This method will also carp if you attempt to add $x to itself or if $x is
-an empty XML::API object.
+This method will also croak if you attempt to add $x to itself or if $x
+is an empty XML::API object.
 
 =head2 $x->_raw($content)
 
